===============================
Deprecated Classes (Docstrings)
===============================

.. deprecated:: 1.13
    :class:`~.Body` and :class:`~.JointsMethod` have been deprecated. The
    functionality of :class:`~.Body` is fully captured by :class:`~.RigidBody`
    and :class:`~.Particle` and the functionality of :class:`~.JointsMethod` is
    fully captured by :class:`~.System`.

.. autoclass:: sympy.physics.mechanics.body.Body
    :members:
    :inherited-members:

.. autoclass:: sympy.physics.mechanics.jointsmethod.JointsMethod
    :members:
    :inherited-members:
